Installation — Documentation audiometry_trainer 0.1.16

# Installation

`audiometry_trainer` a été installé et utilisé avec succès sur Linux et Windows. Il devrait aussi marcher sur des ordinateurs Mac, mais cela n’a pas été testé. Pour Windows, vous pouvez télécharger un programme d’installation dédié sur SourceForge.

Sur Linux et Mac (mais aussi sur Windows si vous ne souhaitez pas utiliser le programme d’installation dédié) `audiometry_trainer`, qui est écrit en Python, peut être installé à travers `pip`:

    pip install audiometry-trainer

`audiometry_trainer` dépend d’un petit nombre de modules Python y compris :

> - PyQt6

> - numpy

> - scipy

> - matplotlib

> - pandas

selon votre distribution il pourrait être souhaitable d’installer ces dépendances avant d’installer `audiometry_trainer` à travers `pip` (par exemple à travers `conda` si vous utilisez la distribution de Python Anaconda, ou à travers votre gestionnaire de paquets de Linux si vous utilisez l’installation de Python de votre distribution Linux), sinon `pip` essayera de télécharger et installer ces dépendances de façon automatique. Si le programme est installé avec succès vous devriez pouvoir le lancer depuis un terminal bash/DOS avec la commande :

    audiometry_trainer

Si vous utilisez plusieurs installations/environnements de Python, vous devez vous assurer que l’environnement de Python que vous employez quand vous utilisez la commande ci-dessus correspond à celui que vous aviez utilisé lors de l’installation de l’application.